#[doc = r" Register block"]
#[repr(C)]
pub struct RegisterBlock {
    #[doc = "0x00 - ADC interrupt and status register"]
    pub isr: ISR,
    #[doc = "0x04 - ADC interrupt enable register"]
    pub ier: IER,
    #[doc = "0x08 - ADC control register"]
    pub cr: CR,
    #[doc = "0x0c - ADC configuration register"]
    pub cfgr: CFGR,
    _reserved0: [u8; 4usize],
    #[doc = "0x14 - ADC sample time register 1"]
    pub smpr1: SMPR1,
    #[doc = "0x18 - ADC sample time register 2"]
    pub smpr2: SMPR2,
    _reserved1: [u8; 4usize],
    #[doc = "0x20 - ADC watchdog threshold register 1"]
    pub tr1: TR1,
    #[doc = "0x24 - ADC watchdog threshold register 2"]
    pub tr2: TR2,
    #[doc = "0x28 - read-write"]
    pub tr3: TR3,
    _reserved2: [u8; 4usize],
    #[doc = "0x30 - ADC regular sequence register 1"]
    pub sqr1: SQR1,
    #[doc = "0x34 - ADC regular sequence register 2"]
    pub sqr2: SQR2,
    #[doc = "0x38 - ADC regular sequence register 3"]
    pub sqr3: SQR3,
    #[doc = "0x3c - ADC regular sequence register 4"]
    pub sqr4: SQR4,
    #[doc = "0x40 - ADC regular Data Register"]
    pub dr: DR,
    _reserved3: [u8; 8usize],
    #[doc = "0x4c - ADC injected sequence register"]
    pub jsqr: JSQR,
    _reserved4: [u8; 16usize],
    #[doc = "0x60 - ADC offset register1"]
    pub ofr1: OFR1,
    #[doc = "0x64 - ADC offset register2"]
    pub ofr2: OFR2,
    #[doc = "0x68 - ADC offset register3"]
    pub ofr3: OFR3,
    #[doc = "0x6c - ADC offset register4"]
    pub ofr4: OFR4,
    _reserved5: [u8; 16usize],
    #[doc = "0x80 - ADC offset register1"]
    pub jdr1: JDR1,
    #[doc = "0x84 - ADC offset register2"]
    pub jdr2: JDR2,
    #[doc = "0x88 - ADC offset register3"]
    pub jdr3: JDR3,
    #[doc = "0x8c - ADC offset register4"]
    pub jdr4: JDR4,
    _reserved6: [u8; 16usize],
    #[doc = "0xa0 - ADC Analog Watchdog 2 Configuration Register"]
    pub awd2cr: AWD2CR,
    #[doc = "0xa4 - ADC Analog Watchdog 3 Configuration Register"]
    pub awd3cr: AWD3CR,
    _reserved7: [u8; 8usize],
    #[doc = "0xb0 - ADC Differential Mode Selection Register"]
    pub difsel: DIFSEL,
    #[doc = "0xb4 - ADC Calibration Factors"]
    pub calfact: CALFACT,
    _reserved8: [u8; 584usize],
    #[doc = "0x300 - ADC Common status register"]
    pub csr: CSR,
}
#[doc = "ADC interrupt and status register"]
pub struct ISR {
    register: ::vcell::VolatileCell<u32>,
}
#[doc = "ADC interrupt and status register"]
pub mod isr;
#[doc = "ADC interrupt enable register"]
pub struct IER {
    register: ::vcell::VolatileCell<u32>,
}
#[doc = "ADC interrupt enable register"]
pub mod ier;
#[doc = "ADC control register"]
pub struct CR {
    register: ::vcell::VolatileCell<u32>,
}
#[doc = "ADC control register"]
pub mod cr;
#[doc = "ADC configuration register"]
pub struct CFGR {
    register: ::vcell::VolatileCell<u32>,
}
#[doc = "ADC configuration register"]
pub mod cfgr;
#[doc = "ADC sample time register 1"]
pub struct SMPR1 {
    register: ::vcell::VolatileCell<u32>,
}
#[doc = "ADC sample time register 1"]
pub mod smpr1;
#[doc = "ADC sample time register 2"]
pub struct SMPR2 {
    register: ::vcell::VolatileCell<u32>,
}
#[doc = "ADC sample time register 2"]
pub mod smpr2;
#[doc = "ADC watchdog threshold register 1"]
pub struct TR1 {
    register: ::vcell::VolatileCell<u32>,
}
#[doc = "ADC watchdog threshold register 1"]
pub mod tr1;
#[doc = "ADC watchdog threshold register 2"]
pub struct TR2 {
    register: ::vcell::VolatileCell<u32>,
}
#[doc = "ADC watchdog threshold register 2"]
pub mod tr2;
#[doc = "read-write"]
pub struct TR3 {
    register: ::vcell::VolatileCell<u32>,
}
#[doc = "read-write"]
pub mod tr3;
#[doc = "ADC regular sequence register 1"]
pub struct SQR1 {
    register: ::vcell::VolatileCell<u32>,
}
#[doc = "ADC regular sequence register 1"]
pub mod sqr1;
#[doc = "ADC regular sequence register 2"]
pub struct SQR2 {
    register: ::vcell::VolatileCell<u32>,
}
#[doc = "ADC regular sequence register 2"]
pub mod sqr2;
#[doc = "ADC regular sequence register 3"]
pub struct SQR3 {
    register: ::vcell::VolatileCell<u32>,
}
#[doc = "ADC regular sequence register 3"]
pub mod sqr3;
#[doc = "ADC regular sequence register 4"]
pub struct SQR4 {
    register: ::vcell::VolatileCell<u32>,
}
#[doc = "ADC regular sequence register 4"]
pub mod sqr4;
#[doc = "ADC regular Data Register"]
pub struct DR {
    register: ::vcell::VolatileCell<u32>,
}
#[doc = "ADC regular Data Register"]
pub mod dr;
#[doc = "ADC injected sequence register"]
pub struct JSQR {
    register: ::vcell::VolatileCell<u32>,
}
#[doc = "ADC injected sequence register"]
pub mod jsqr;
#[doc = "ADC offset register1"]
pub struct OFR1 {
    register: ::vcell::VolatileCell<u32>,
}
#[doc = "ADC offset register1"]
pub mod ofr1;
#[doc = "ADC offset register2"]
pub struct OFR2 {
    register: ::vcell::VolatileCell<u32>,
}
#[doc = "ADC offset register2"]
pub mod ofr2;
#[doc = "ADC offset register3"]
pub struct OFR3 {
    register: ::vcell::VolatileCell<u32>,
}
#[doc = "ADC offset register3"]
pub mod ofr3;
#[doc = "ADC offset register4"]
pub struct OFR4 {
    register: ::vcell::VolatileCell<u32>,
}
#[doc = "ADC offset register4"]
pub mod ofr4;
#[doc = "ADC offset register1"]
pub struct JDR1 {
    register: ::vcell::VolatileCell<u32>,
}
#[doc = "ADC offset register1"]
pub mod jdr1;
#[doc = "ADC offset register2"]
pub struct JDR2 {
    register: ::vcell::VolatileCell<u32>,
}
#[doc = "ADC offset register2"]
pub mod jdr2;
#[doc = "ADC offset register3"]
pub struct JDR3 {
    register: ::vcell::VolatileCell<u32>,
}
#[doc = "ADC offset register3"]
pub mod jdr3;
#[doc = "ADC offset register4"]
pub struct JDR4 {
    register: ::vcell::VolatileCell<u32>,
}
#[doc = "ADC offset register4"]
pub mod jdr4;
#[doc = "ADC Analog Watchdog 2 Configuration Register"]
pub struct AWD2CR {
    register: ::vcell::VolatileCell<u32>,
}
#[doc = "ADC Analog Watchdog 2 Configuration Register"]
pub mod awd2cr;
#[doc = "ADC Analog Watchdog 3 Configuration Register"]
pub struct AWD3CR {
    register: ::vcell::VolatileCell<u32>,
}
#[doc = "ADC Analog Watchdog 3 Configuration Register"]
pub mod awd3cr;
#[doc = "ADC Differential Mode Selection Register"]
pub struct DIFSEL {
    register: ::vcell::VolatileCell<u32>,
}
#[doc = "ADC Differential Mode Selection Register"]
pub mod difsel;
#[doc = "ADC Calibration Factors"]
pub struct CALFACT {
    register: ::vcell::VolatileCell<u32>,
}
#[doc = "ADC Calibration Factors"]
pub mod calfact;
#[doc = "ADC Common status register"]
pub struct CSR {
    register: ::vcell::VolatileCell<u32>,
}
#[doc = "ADC Common status register"]
pub mod csr;
#[doc = "ADC common control register"]
pub struct CRR {
    register: ::vcell::VolatileCell<u32>,
}
#[doc = "ADC common control register"]
pub mod crr;
